.. _builder_concept:

===========
The Builder
===========

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------

- The setup method
- The builder wraps up services
- Detail of services
